@@ -1,11 +1,9 @@
 import click
 import time
-import json
 import logging
 import os
 
-
-from . import TestSuite, TestCase, Tests, validation, Executable
+from . import TestSuite, TestGroup, TestCase, Executable
 
 
 def display_pad(pad=0):
@@ -46,10 +44,8 @@ class Runner:
         self.verbose = verbose
         self.executable = executable
         self.limit = -1 if 'limit' not in kwargs else kwargs['limit']
-        self.filename = validation.find_testfile()
-        self.test_description = Tests(self.filename)
-        self.test_suite = TestSuite(
-            self.test_description, Executable(self.executable))
+
+        self.test_suite = TestSuite(executable=Executable(self.executable))
 
     def _init_logger(self, loglevel):
         handler = logging.StreamHandler()
@@ -68,7 +64,6 @@ class Runner:
 
         self._traverse_group(self.test_suite)
 
-
         click.secho('\nRan %d tests in %ss.' % (
             self.successes + self.failures,
             round(time.time() - start_time, 2)
@@ -77,7 +72,8 @@ class Runner:
         if self.failures > 0:
             click.secho('%d failed, %d passed (%d%% ok).' % (
                 self.failures, self.successes,
-                100-round(self.failures/self.successes*100, 2)), fg='yellow', bold=True)
+                100 - round(self.failures / (self.failures + self.successes) * 100, 2)
+            ), fg='yellow', bold=True)
             click.secho('\nfail.', fg='red', bold=True)
         else:
             click.secho('\nok.', fg='green')
@@ -99,7 +95,7 @@ class Runner:
             if self.limit > 0 and self.failures > self.limit:
                 break
 
-            if isinstance(test, TestSuite):
+            if isinstance(test, TestGroup):
                 display_test_name(test)
                 click.echo('')
                 self._traverse_group(test)
@@ -114,8 +110,8 @@ class Runner:
                     self.failures += 1
                     click.secho(' FAILED', fg='red', bold=True)
                     for issue in issues:
-                        click.secho('  ' * len(test._id) + '- ' + 
-                                    str(issue), fg='magenta', bold=True)
+                        click.secho('  ' * len(test._id) + '- ' + str(issue),
+                                    fg='magenta', bold=True)
         return self.failures
 
 
