@@ -1,4 +1,6 @@
-from voluptuous import Schema, ExactSequence, IsFile, Coerce, Required, Any, All, Number, Optional
+from voluptuous import (Schema, ExactSequence, IsFile,
+                        Coerce, Required,
+                        Any, All, Number, Optional)
 
 match = Any(
     All(Number(), Coerce(str), lambda x: [{'equals': x}]),
@@ -15,12 +17,12 @@ match = Any(
 )
 
 test = Schema({
-    Optional('name'): str,
-    Optional('args'): [Any(str, All(Number(), Coerce(str)))],
+    Optional('name', default=''): str,
+    Optional('args', default=[]): [Any(str, All(Number(), Coerce(str)))],
     Optional('stdin', default=None): Any(None, str, [str]),
     Optional('stdout', default=[]): match,
     Optional('stderr', default=[]): match,
-    Optional('exit-status'): All(Any(int, bool), Coerce(int))
+    Optional('exit'): All(Any(int, bool), Coerce(int))
 })
 
 group = Schema({
@@ -29,10 +31,10 @@ group = Schema({
 })
 
 schema = Schema({
-    Required('version'): 1,
+    Optional('version', default=1): 1,
     Optional('name', default=''): str,
-    Optional('executable'): IsFile('Missing configuration file'),
-    Optional('filters'): {
+    Optional('executable', default=None): Any(IsFile('Missing configuration file'), None),
+    Optional('filters', default={}): {
         Optional('uppercase'): bool,
         Optional('lowercase'): bool,
         Optional('trim'): bool,
